@@ -4,7 +4,7 @@ import urllib.parse
 
 from lesscode_flask.utils.request.request import get_basic_auth, sync_common_request_origin
 from redash.query_runner import *
-from redash.utils import json_dumps, json_loads
+from redash.utils import json_loads
 
 logger = logging.getLogger(__name__)
 
@@ -52,9 +52,23 @@ class BaseElasticSearch(BaseQueryRunner):
             "required": ["server"],
         }
 
+    def create_options(self, configuration):
+        options = {
+            "server": f'http://{configuration.get("host")}:{configuration.get("port")}/{configuration.get("dbname")}',
+            "server_url": f'http://{configuration.get("host")}:{configuration.get("port")}',
+            "basic_auth_user": configuration.get("username"),
+            "basic_auth_password": configuration.get("password")
+        }
+        if configuration.get("options"):
+            options.update(configuration.get("options"))
+        return options
+
+    def get_password_field(self):
+        return "basic_auth_password"
+
     @classmethod
     def enabled(cls):
-        return False
+        return True
 
     def __init__(self, configuration):
         super(BaseElasticSearch, self).__init__(configuration)
@@ -70,17 +84,16 @@ class BaseElasticSearch(BaseQueryRunner):
 
             logger.setLevel(logging.DEBUG)
 
-        self.server_url = self.configuration["server"]
-        if self.server_url[-1] == "/":
-            self.server_url = self.server_url[:-1]
-
+    def _init_connection(self):
         basic_auth_user = self.configuration.get("basic_auth_user", None)
         basic_auth_password = self.configuration.get("basic_auth_password", None)
         self.auth = None
         if basic_auth_user and basic_auth_password:
             self.auth = get_basic_auth(basic_auth_user, basic_auth_password)
+        self.server_url = self.configuration.get("server_url")
 
     def _get_mappings(self, url):
+        self._init_connection()
         error = None
         try:
             r = sync_common_request_origin(url=url, method="get", auth=self.auth)
@@ -321,6 +334,7 @@ class BaseElasticSearch(BaseQueryRunner):
             )
 
     def test_connection(self):
+        self._init_connection()
         try:
             r = sync_common_request_origin(url="{0}/_cluster/health".format(self.server_url), method="get",
                                            auth=self.auth
@@ -339,8 +353,7 @@ class Kibana(BaseElasticSearch):
     def _execute_simple_query(
             self, url, auth, _from, mappings, result_fields, result_columns, result_rows
     ):
-        url += "&from={0}".format(_from)
-        r = sync_common_request_origin(url=url, method="get", auth=self.auth)
+        r = sync_common_request_origin(url=url, method="get", auth=auth)
         r.raise_for_status()
 
         raw_result = r.json()
@@ -358,7 +371,7 @@ class Kibana(BaseElasticSearch):
     def run_query(self, query, user):
         try:
             error = None
-
+            self._init_connection()
             logger.debug(query)
             query_params = json_loads(query)
 
@@ -432,7 +445,7 @@ class ElasticSearch(BaseElasticSearch):
     def run_query(self, query, user):
         try:
             error = None
-
+            self._init_connection()
             logger.debug(query)
             query_dict = json_loads(query)
 
@@ -452,17 +465,10 @@ class ElasticSearch(BaseElasticSearch):
 
             logger.debug("Using URL: %s", url)
             logger.debug("Using query: %s", query_dict)
-            r = sync_common_request_origin(url=url, method="get", json=query_dict, auth=self.auth)
+            r = sync_common_request_origin(url=url, method="post", json=query_dict, auth=self.auth)
             r.raise_for_status()
             logger.debug("Result: %s", r.json())
-
-            result_columns = []
-            result_rows = []
-            self._parse_results(
-                mappings, result_fields, r.json(), result_columns, result_rows
-            )
-
-            json_data = json_dumps({"columns": result_columns, "rows": result_rows})
+            return r.json(), None
         except Exception as e:
             logger.exception(e)
             error = f"Failed to execute query.  Reason: {e}"
